@@ -1,31 +1,18 @@
-# This file is part of TMart.
+# This file is part of T-Mart.
 #
-# Copyright 2022 Yulun Wu.
+# Copyright 2023 Yulun Wu.
 #
 # T-Mart is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
-
-
-
-
-
 # Replacing tm
-
 # function as second page 
-
 # Overall control of photon movement
 
-
-
-
-
-
 # T-MART: Topography-adjusted Monte-Carlo Adjacency-effect Radiative Transfer code  
 
-
 import sys
 import numpy as np
 import pandas as pd
@@ -34,25 +21,19 @@ import math
 from scipy.interpolate import interp1d
 from copy import copy
 
+from .tm_move import pt_move
+from .tm_OT import find_OT
 from .tm_sampling import sample_Lambertian, sample_scattering, weight_impSampling
 from .tm_geometry import dirP_to_coord, dirC_to_dirP, rotation_matrix, angle_3d, dirC_to_coord
 from .tm_intersect import find_atm2, intersect_line_DEMtri2
 from .tm_intersect import reflectance_intersect, reflectance_background, intersect_background
 from .tm_water import fresnel, sample_cox_munk, find_R_cm
 
-from .tm_move import pt_move
-from .tm_OT import find_OT
-
-
-
 # Plotting 
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
 from mpl_toolkits.mplot3d.art3d import Poly3DCollection
 
-
-
-
 # The class is overwritten in Tmart 
 class Tmart2(): 
 
@@ -68,17 +49,14 @@ class Tmart2():
         # numpy atmospheric profile, to runs faster 
         atm_profile = self.atm_profile_wl.sort_values('Alt_bottom').to_numpy()
         
-
         # Initial position of the photon 
         if self.pixel == None:
             q0 = self.sensor_coords
         else:
             pixel_x = self.Surface.cell_size * (self.pixel[1] + random.random()) # X
             pixel_y = self.Surface.cell_size * (self.pixel[0] + random.random()) # Y
-
             q0 = self.sensor_coords + [pixel_x,pixel_y,self.pixel_elevation]
             
-        
         # Initial moving direction of the photon
         
         if self.target_pt_direction == 'lambertian_up': 
@@ -102,7 +80,6 @@ class Tmart2():
         # A numpy array to collect information, here 14 columns, local_estimate has 14 too, output only 13
         pt_stat = np.empty((0,14))     
         
-        
         ### For loop: photon movements 
         for movement in range(0, 500): 
             
@@ -113,21 +90,13 @@ class Tmart2():
             q1, tao_abs, ot_rayleigh_NA, ot_mie_NA, out = pt_move(atm_profile,q0,pt_direction,sampled_tao)
             # note: ot_rayleigh and ot_mie are replaced later, the accumulated ot should not be used, thus add _NA to mask them
     
-    
             if self.print_on:
-                print ('\nq0: ' +str(q0))
-                print ('q1: ' +str(q1))
-                print ('tao_abs: ' +str(tao_abs))
-                print('sampled_tao: ' + str(sampled_tao))
-                print ('pt_direction: ' +str(pt_direction))
-                print('out: ' + str(out)) 
-            
-            
-            
-            ### Test atm intrinsic reflectance 
-            # if q0[2] <0 or q1[2] < 0:
-            #     break
-            
+                print ('\nInitial position: ' +str(q0))
+                print ('Final position: ' +str(q1))
+                print ('Absorption optical thickness (OT): ' +str(tao_abs))
+                print('Sampled OT: ' + str(sampled_tao))
+                print ('Photon moving direction: ' +str(pt_direction))
+                print('If out of atmosphere: ' + str(out)) 
             
             ### Test triangle collision             
 
@@ -140,13 +109,13 @@ class Tmart2():
                 intersect_tri = intersect_line_DEMtri2(q0, q1, self.Surface.DEM_triangulated, self.print_on)      
             
             
-            
             ###### Three scenarios 
             
             # 1 Triangle collision 
             # 2 Background collision 
             # 3 Photon movement and scattering 
             
+            
             # If there is triangle intersection 
             if intersect_tri.shape[0] > 0:
                 if self.print_on: print ("\nScenario 1: Triangle collision")
@@ -169,14 +138,12 @@ class Tmart2():
             
             
             ### Black surface acceleration
-            
             if (scenario == 1 or scenario == 2) and black_surface: 
                 if self.print_on: print ("\n=== Black surface acceleration, exit ===")
                 break
 
             
             ### Triangle Collision 
-            
             if scenario == 1:
                 
                 rotated_cm = None
@@ -185,7 +152,7 @@ class Tmart2():
                 intersect_tri_chosen = intersect_tri.iloc[intersect_tri.linear_distance.idxmin()] 
                 q_collision = intersect_tri_chosen.tolist()[0:3]  
                 
-                if self.print_on: print('q_collision: ' + str(q_collision))    
+                if self.print_on: print('Collision position: ' + str(q_collision))    
                 
                 # Re-calculate absorption 
                 tao_abs = find_OT(q0,q_collision,atm_profile)
@@ -206,7 +173,7 @@ class Tmart2():
                 q_collision_ref = reflectance_intersect(q_collision, self.Surface.reflectance, 
                                                         self.Surface.cell_size, self.Surface.bg_ref, 
                                                         self.Surface.bg_coords)
-                if self.print_on: print("q_collision_ref: " + str(q_collision_ref))    
+                if self.print_on: print("Reflectance at collision position: " + str(q_collision_ref))    
                 
             
                 ### If water --> there is a chance of specular reflectance             
@@ -217,7 +184,7 @@ class Tmart2():
                 q_collision_isWater = reflectance_intersect(q_collision, self.Surface.isWater, 
                                                             self.Surface.cell_size, self.Surface.bg_isWater, 
                                                             self.Surface.bg_coords)    
-                if self.print_on: print('\nq_collision_isWater: '+str(q_collision_isWater))
+                if self.print_on: print('\nIf surface is water: '+str(q_collision_isWater))
                 
     
                 # By default, non-specular. If chance, switch on 
@@ -264,10 +231,9 @@ class Tmart2():
                     # '(1-self.F_wc_wl) * q_collision_ref' is R0+ in the presence of white caps 
                     q_collision_ref = R_surf + (1-self.F_wc_wl) * q_collision_ref
                     
-                    
-                    # if chance (R_specular) out of q_collision_ref, siwtch on specular_on
+                    # If chance (R_specular) out of q_collision_ref, siwtch on specular_on
                     specular_on = random.uniform(0,q_collision_ref) < R_specular
-                    # specular_on = True # 强制specular, just testing!!!
+                    # specular_on = True # for testing
                     
                     if self.print_on: 
                         print('random_cox_munk: ' + str(random_cox_munk))
@@ -278,13 +244,13 @@ class Tmart2():
                         print('R_fresnel: ' + str(R_specular))
                         print('R_surf: ' + str(R_surf))
                         print('specular_on: ' + str(specular_on))
-                        print("Modified q_collision_ref: " + str(q_collision_ref))  
+                        # print("Modified reflectance at collision position: " + str(q_collision_ref))  
                           
                 pt_weight = pt_weight * q_collision_ref
                  
                 # If water and specular 
                 if q_collision_isWater == 1 and specular_on:
-                    if self.print_on: print('\n==Specular reflection==')  
+                    if self.print_on: print('\n== Specular reflection ==')  
                     
                     # Rotate pt_direction_op_C  around rotated_cm by 180 degrees       
                     rotated = np.dot(rotation_matrix(rotated_cm, math.pi), pt_direction_op_C)
@@ -315,14 +281,12 @@ class Tmart2():
                     if self.print_on:
                         print("\nRandom_lambertian: " + str(random_lambertian))
                         print("Rotated_lambertian: " + str(rotated)) 
-                        print("q_collision_ref: " + str(q_collision_ref))
+                        # print("q_collision_ref: " + str(q_collision_ref))
                         
-                if self.print_on: print("pt_weight before absorption: " + str(pt_weight))      
-                
+                if self.print_on: print("Photon weight before absorption: " + str(pt_weight))      
                 
                 
             ### Background collision     
-             
             elif scenario == 2:
                 
                 # For plotting, not used 
@@ -331,7 +295,7 @@ class Tmart2():
                 
                 
                 q_collision = intersect_bg 
-                if self.print_on: print('q_collision: ' + str(q_collision))  
+                if self.print_on: print('Collision position: ' + str(q_collision))  
                 
                 # re-calculate absorption 
                 tao_abs = find_OT(q0,q_collision,atm_profile)
@@ -344,13 +308,13 @@ class Tmart2():
                 q_collision_ref = reflectance_background(q_collision,self.Surface.bg_ref, self.Surface.bg_coords)
                 if self.print_on:
                     print ('\nOut of the padded DEM')
-                    print("q_collision_ref: " + str(q_collision_ref))
+                    print("Reflectance at collision position: " + str(q_collision_ref))
                 
                 # Test if it's water at the collision point 
                 q_collision_isWater = reflectance_intersect(q_collision, self.Surface.isWater, 
                                                             self.Surface.cell_size, self.Surface.bg_isWater, 
                                                             self.Surface.bg_coords)    
-                if self.print_on: print('\nq_collision_isWater: '+str(q_collision_isWater))                    
+                if self.print_on: print('\nIf surface is water: '+str(q_collision_isWater))                    
                 specular_on = False
                 
                 # If water, calculate Fresnel reflectance and if specular reflection   
@@ -392,13 +356,13 @@ class Tmart2():
                         print('R_fresnel: ' + str(R_specular))
                         print('R_surf: ' + str(R_surf))
                         print('specular_on: ' + str(specular_on))   
-                        print("Modified q_collision_ref: " + str(q_collision_ref))  
+                        # print("Modified reflectance at collision position: " + str(q_collision_ref))  
                 
                 pt_weight = pt_weight * q_collision_ref   
                 
                 # if water and specular 
                 if q_collision_isWater == 1 and specular_on:
-                    if self.print_on: print('\n==Specular reflection==')  
+                    if self.print_on: print('\n== Specular reflection ==')  
                         
                     rotated = np.dot(rotation_matrix(random_cox_munk, math.pi), pt_direction_op_C)
        
@@ -411,29 +375,25 @@ class Tmart2():
                     pt_direction = sample_Lambertian()[1]
                     tpye_collision = 'W'
                         
-                if self.print_on: print("pt_weight before absorption: " + str(pt_weight))               
+                if self.print_on: print("Photon weight before absorption: " + str(pt_weight))               
             
             
             ### Photon movement and scattering 
-            
             elif scenario == 3:
-                
                 q_collision = q1
                 
                 ### Find ot_mie and ot_rayleigh
                 ot_rayleigh, ot_mie = find_atm2(atm_profile,q1)
-                
                 pt_direction_op_C = np.negative(dirP_to_coord(1, pt_direction))
                 
-                
                 # regular sampling  
                 if random.random() >= self.VROOM:
-                    if self.print_on: print('\n==Regular Sampling==')  
+                    if self.print_on: print('\n== Regular Sampling ==')  
                     pt_direction, scatt_intensity, type_scat = sample_scattering(ot_mie, ot_rayleigh, pt_direction, self.aerosol_SPF_wl, self.print_on)
     
                 # importance sampling 
                 else:
-                    if self.print_on: print('\n==Importance Sampling==')  
+                    if self.print_on: print('\n== Importance Sampling ==')  
                     
                     # Force mie scattering when importance sampling 
                     pt_direction, scatt_intensity, type_scat = sample_scattering(1, 0, self.sun_dir, self.Atmosphere.aerosol_SPF, self.print_on)
@@ -448,13 +408,7 @@ class Tmart2():
                     if self.print_on: print("  adjustment factor: " + str(scatt_intensity_impSampling/scatt_intensity))
                     pt_weight = pt_weight * (scatt_intensity_impSampling/scatt_intensity)
  
-                    
-    
-    
-
-
-
-    
+                
             
             ###### Calculate absorption 
           
@@ -462,28 +416,12 @@ class Tmart2():
             pt_weight = pt_weight * T_abs
             
             if self.print_on:
-                print('\n= Absorption =')
-                print("tao_abs: " + str(tao_abs))
-                print("T_abs: " + str(T_abs))
-                print("pt_weight: " + str(pt_weight))
-                print('\n= Local estimate =')
-            
-            
-            ''' to be deleted
-            
-            # 1000 -> self.pixel_elevation 
-            # 30 -> self.sun_dir[0]
-            
-            sun_dir = [30,0]
-            q_collision = np.array([0,0,1000])
-            
-            dist_120000 = (120_000 - 1000) / np.cos(30/180*np.pi) 
-            
-            q_sun = dirP_to_coord(dist_120000, sun_dir) + q_collision
-            
-            '''
-            
-            
+                print('\n== Calculating absorption ==')
+                print("Modified absorption OT: " + str(tao_abs))
+                print("Absorption transmittance: " + str(T_abs))
+                print("Photon weight: " + str(pt_weight))
+                
+                      
             
             ###### Local estimates 
             
@@ -496,6 +434,7 @@ class Tmart2():
             
             # Reflection 
             if scenario == 1 or scenario == 2: 
+                if self.print_on: print('\n== Calculating local estimate ==')
                 
                 if movement == 0:
                     is_env = 0
@@ -503,14 +442,9 @@ class Tmart2():
                     is_env = 1
                 
                 if self.shadow: if_shadow = self.detect_shadow(q_collision)
-                    
-                ### not using this anymore, cause trouble in RTM calculation 
-                # if if_shadow: 
-                #     local_est = [pt_id, movement,'Shadow',0,0,0,0,0,0] + q_collision
                 
                 # Water
                 if q_collision_isWater==1:
-                    
                     le_water = self.local_est_water(pt_weight, pt_direction_op_C, q_collision, 
                                                     q_collision_N_polar, R_specular, q_collision_ref, R_surf)
                     local_est = [pt_id, movement] + le_water + [0,0,0] + q_collision + [0,is_env,tpye_collision]
@@ -520,41 +454,24 @@ class Tmart2():
                     le_land = self.local_est_land(q_collision, pt_weight)
                     local_est = [pt_id, movement,0,0,0] + le_land + [0,0] + q_collision + [0,is_env,'L']
                 
-                
                 if if_shadow: local_est[11] = 1
-                
                 if self.print_on: print("local_est: " + str(local_est))
-
-                
                 pt_stat = np.vstack([pt_stat, local_est])     
                 
             # Scattering 
             if scenario == 3 and out == False:
+                if self.print_on: print('\n== Calculating local estimate ==')
                 
                 if self.shadow: if_shadow = self.detect_shadow(q_collision)
-                    
-                ### same as above
-                # if if_shadow: 
-                #     local_est = [pt_id, movement,'Shadow',0,0,0,0,0,0] + q_collision.tolist() 
-                #     # tolist because q_collision comes from q1, which is a numpy array
-                    
                 le_scatt = self.local_est_scat(pt_direction_op_C, q_collision, pt_weight, ot_mie, ot_rayleigh)
-                
                 local_est = [pt_id, movement,0,0,0,0] + le_scatt + q_collision.tolist() + [0,0,type_scat]
-                
                 if if_shadow: local_est[11] = 1
-                
                 if self.print_on: print("local_est: " + str(local_est))
-                
                 pt_stat = np.vstack([pt_stat, local_est])            
             
             
-            
-            
-            
             ###### Plot and out 
             
-        
             # Plotting, only supposed to be run by self.run_plot()
             if self.plot_on:
                 
@@ -563,13 +480,10 @@ class Tmart2():
                 
                 else: 
                     self._plot(q0, q_collision, scenario)
-           
-
         
             # Exit if out 
             if out:
-                    
-                # Record information ???
+                if self.print_on: print('\nPhoton out of atmosphere \n')
                 break
         
             if self.print_on: print("\n------- Movement {} -------".format(movement+2))  
@@ -579,7 +493,6 @@ class Tmart2():
             # starting the next movement at the collision         
             q0 = q_collision
         
-        
         pt_stat = self._diff_ref(pt_stat)
         
         # return np.array([surface_irradiance]) # for surface_irradiance 
@@ -590,7 +503,6 @@ class Tmart2():
     def _diff_ref (self,pt_stat):
         
         pt_stat_num = pt_stat[:,0:13].astype(float)
-        
         moves = pt_stat_num[:,1].astype(int)
         
         if not np.all(np.diff(moves) > 0): # check if sorted 
@@ -654,7 +566,6 @@ class Tmart2():
                 
                 pt_movement[0][2] = total + sum_after
                 
-                
                 pt_stat_output = np.vstack([pt_stat_output, pt_movement])
                 
                 break         
@@ -664,20 +575,17 @@ class Tmart2():
             
         return pt_stat_output
         
-
-
     def local_est_scat(self,pt_direction_op_C,q_collision, pt_weight, ot_mie, ot_rayleigh):
         
         # calculate remaining Transmittance 
         OT = self._local_est_OT(q_collision)
         OT = OT / math.cos(self.sun_dir[0]/180*math.pi)
         T = math.exp(-OT)
-        if self.print_on: print ('\nT_total for local_est: ' +str(T))
+        if self.print_on: print ('\nTotal transmittance for local_est: ' +str(T))
         
         # total scattering in that layer 
         ot_scattering = ot_mie + ot_rayleigh
         
-        
         # angle between pt_direction and the sun 
         angle_pt_sun = angle_3d(dirP_to_coord(1,self.sun_dir), [0,0,0], pt_direction_op_C)
         
@@ -686,14 +594,8 @@ class Tmart2():
         
         # rayleigh 
         rayleigh = (3/4)*(1+(math.cos(angle_scattering/180*math.pi))**2)
-        # print('rayleigh: ' + str(rayleigh))
-        
-        # c: contribution? 
-        
         rayleigh_c = rayleigh / math.cos(self.sun_dir[0]/180*math.pi)  / 4 # 4 should be the right normalization 
-        # print('rayleigh_c: ' + str(rayleigh_c))
         rayleigh_c = rayleigh_c * (ot_rayleigh/ot_scattering)
-        # print('rayleigh_c2: ' + str(rayleigh_c))
     
         # mie
         df_angle = self.aerosol_SPF_wl.Angle.to_numpy()
@@ -704,54 +606,45 @@ class Tmart2():
         mie_c = mie / math.cos(self.sun_dir[0]/180*math.pi) / 4 # / math.pi   
         mie_c = mie_c * (ot_mie/ot_scattering)
         
-        
         local_est = np.array([rayleigh_c, mie_c]) * T * pt_weight / 1_000_000   
-        
-        # print('local_est: ' + str(local_est))
-        
         return local_est.tolist()
 
-
-
     def local_est_land(self, q_collision, pt_weight): 
     
         # Direct transmittance 
         OT = self._local_est_OT(q_collision)
         OT = OT / math.cos(self.sun_dir[0]/180*math.pi)
         T = math.exp(-OT)
-        if self.print_on: print ('\nT_total for local_est: ' +str(T))
+        if self.print_on: print ('\nTotal transmittance for local_est: ' +str(T))
         
         local_est = pt_weight * T / 1_000_000
         return [local_est]
    
-    
-      
     def local_est_water(self, pt_weight, pt_direction_op_C, q_collision, q_collision_N_polar, R_specular, q_collision_ref, R_surf):   
         
         R_wc = self.R_wc_wl
         
-        # Cox-Munk and Fresnel, this one tells us nothing about the actual flux reflectance!!!  
+        # Cox-Munk and Fresnel, this one tells us nothing about the actual flux reflectance!
         R_cm = find_R_cm(pt_direction_op_C, self.sun_dir, q_collision_N_polar, 
                          self.wind_dir, self.wind_speed, self.water_refraIdx_wl, self.print_on)
         
         # Average = (regular + wind 90 degrees) / 2
         if self.wind_azi_avg:
-            if self.print_on: print ('\nSampling R_cm again...')
+            if self.print_on: print ('\nSampling R_cm again for azimuthally averaged values')
             
             R_cm2 = find_R_cm(pt_direction_op_C, self.sun_dir, q_collision_N_polar, 
                               self.wind_dir + 90, self.wind_speed, self.water_refraIdx_wl, self.print_on)
             R_cm = (R_cm + R_cm2) / 2
             
-        
-        
         R_cm = (1-self.F_wc_wl) * R_cm # remove whitecaps from cox-munk reflection 
+        if self.print_on:print('\nFinal cox_munk reflectance: '+str(R_cm))
         
         # Dicrect transmittance 
         OT = self._local_est_OT(q_collision)
         OT = OT / math.cos(self.sun_dir[0]/180*math.pi)
         T = math.exp(-OT)
         
-        if self.print_on: print ('\nT_total for local_est: ' +str(T))
+        if self.print_on: print ('\nTotal transmittance for local_est: ' +str(T))
             
         # cox-munk
         pt_weight_cm = pt_weight * (R_cm / q_collision_ref) 
@@ -779,80 +672,50 @@ class Tmart2():
         
         if_shadow = intersect_tri.shape[0] > 0
         
-        if self.print_on: print ('\nif_shadow: ' +str(if_shadow))
+        if self.print_on: print ('\nIf shaded: ' +str(if_shadow))
         
         return if_shadow
         
 
     # finds OT between TOA and z
-    
     def _local_est_OT(self,q_collision): 
-        # print('OT_abs of entire atm: {}'.format(sum(self.atm_profile_wl.ot_abs)))
         
         # Altitude of the collision point  
         z = q_collision[2]
  
         # Find all layers whose bottoms are equal to or higher than z, panda series Boolean 
         alts_higher = np.array(self.atm_profile_wl.Alt_bottom *1000 >= z)
-        # print ('alts_higher: ' +str(alts_higher))
-        
-        
 
         # Calculate OTs in layers above, capital is output 
         OT_out = (sum(self.atm_profile_wl.ot_abs[alts_higher]) +  
                       sum(self.atm_profile_wl.ot_rayleigh[alts_higher]) + 
                       sum(self.atm_profile_wl.ot_mie[alts_higher]) )   
-        # print ('OT_abs_out, sum of all above: ' +str(OT_abs_out))
-
 
         # boolean if equal 
         alts_equal = np.array( self.atm_profile_wl.Alt_bottom * 1000 == z )
-        # print ('alts_equal: ' +str(alts_equal))
-        # print ('sum alts_equal: ' +str(sum(alts_equal)))
         
         if sum(alts_equal): 
-            # print('Find euqal altitude')
             pass
         else: # Alternative: find the layer where Z is in, find OT_remain_ratio...
-            # print('No equal altitudes, calculating remaining OT_abs')
             
             # calculate top altitudes - collision altitude
             alts_diff = (self.atm_profile_wl.Alt_top - z/1000)
-            # print ('alts_diff: ' +str(alts_diff))
             
             alts_diff_positive_min = alts_diff[alts_diff>0].min()
-            # print ('alts_diff_positive_min: ' +str(alts_diff_positive_min))
-            
             
             # edited 
             alts_diff_positive_min_idx = alts_diff[alts_diff>0].idxmin()
-            # print ('alts_diff_positive_min_idx: ' +str(alts_diff_positive_min_idx))   
-            
             height = self.atm_profile_wl.Alt_top[alts_diff_positive_min_idx] - self.atm_profile_wl.Alt_bottom[alts_diff_positive_min_idx]
-            
-            
-            OT_remain_ratio = alts_diff_positive_min / height
-            # print ('OT_remain_ratio: ' +str(OT_remain_ratio))            
-            
+            OT_remain_ratio = alts_diff_positive_min / height        
             
             OT_layer = (self.atm_profile_wl.ot_abs[alts_diff_positive_min_idx] + 
                         self.atm_profile_wl.ot_rayleigh[alts_diff_positive_min_idx] + 
                         self.atm_profile_wl.ot_mie[alts_diff_positive_min_idx]  ) 
             
-            # OT_layer = (self.atm_profile_wl.ot_scatt[alts_diff_positive_min_idx]  ) # test         
-            
-            
-            # print ('ot_abs: ' +str(ot_abs))
-            
             OT_abs_remain = OT_layer * OT_remain_ratio 
-            # print ('OT_abs_remain: ' +str(OT_abs_remain))
-            
             OT_out = OT_out + OT_abs_remain
         return OT_out
 
-
-
-
     def _plot(self,q0,q1, scenario, intersect_tri_chosen=None, rotated=None, q_collision_N=None, specular_on=False, rotated_cm=None, linewidth=2.5):
         
         
@@ -860,9 +723,7 @@ class Tmart2():
         ax = Axes3D(fig, auto_add_to_figure=False)
         fig.add_axes(ax)
         
-        #ax.invert_xaxis()
-        
-        
+        # ax.invert_xaxis()
         # ax.set_xlim(0, 100_000 * 1) 
         # ax.set_ylim(100_000 * 1, 0 )
         # ax.set_zlim(0, 100_000 * 1 )   
@@ -871,42 +732,30 @@ class Tmart2():
         ax.set_ylim(self.plot_range[3],self.plot_range[2])
         ax.set_zlim(self.plot_range[4],self.plot_range[5])   
         
-        
         ax.set_xlabel('X axis (m)')
         ax.set_ylabel('Y axis (m)')
         ax.set_zlabel('Z axis (m)')
         
-        
         # Plotting DEM_tri
         for tri in self.Surface.DEM_triangulated:
             for row in range (0, tri.shape[2]):
                 for col in range (0, tri.shape[3]):
-                    # print (row, col)
             
                     p0 = tri[0,:,row,col] 
                     p1 = tri[1,:,row,col]
                     p2 = tri[2,:,row,col]
                     
-                    plot_tri = [p0,p1,p2]
-                    
-                    plot_tri = np.array([p0,p1,p2])
-                    
-                    
-                    # print("------")
-                    # print('plot_tri: ' + str(plot_tri))
+                    plot_tri = np.array([[p0,p1,p2]])
                     
                     p_centre = (p0 + p1 + p2)/3
-                    # print('p_centre: ' + str(p_centre))
                     
                     q_collision_ref = reflectance_intersect(p_centre, self.Surface.reflectance, 
                                                             self.Surface.cell_size, self.Surface.bg_ref, 
                                                             self.Surface.bg_coords)    
-                    # print('q_collision_ref: ' + str(q_collision_ref))
                     
                     if q_collision_ref>1: q_collision_ref=1
                     if q_collision_ref<0: q_collision_ref=0
                     
-                    
                     poly = Poly3DCollection(plot_tri,
                                 #facecolors='ivory',
                                 facecolors=str(q_collision_ref),
@@ -937,9 +786,7 @@ class Tmart2():
             
             # Manual length of the other two lines 
             my_length = 50_000
-            # my_length = 1
-            
-            
+
             if self.print_on: print ("\nPlotting triangle collision")
         
             triangle = intersect_tri_chosen.tolist()
@@ -963,12 +810,8 @@ class Tmart2():
             
             # reflected direction 
             reflected_viz_q1 = triangle[0:3] + rotated * 33_000
-            # print('==============================')
-            # print(reflected_viz_q1)
-            
 
             # new pt_direction 
-            
             ax.plot([triangle[0] , reflected_viz_q1[0]],
                     [triangle[1] ,  reflected_viz_q1[1]],
                     zs=[triangle[2] ,  reflected_viz_q1[2]],
@@ -977,27 +820,8 @@ class Tmart2():
                     linewidth = linewidth
                     )
             
-            if self.print_on: print("Angle between normal and new pt_direction is: " + 
+            if self.print_on: print("Angle between normal and new moving direction is: " + 
                                     str(angle_3d(rotated,[0,0,0],q_collision_N)))
-        
     
         # Plot atmospheres to the same extend as the surface 
-        
         plt.show()
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
